@@ -3,7 +3,7 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.1.0";
+const QString appVersion = "1.1.1";
 
 void maemoBanner(QString string)
 {
@@ -314,8 +314,10 @@ void MainWindow::on_editStationButton_clicked()
     int currentIndex = ui->stationsList->currentRow();
     if ( currentIndex == -1) return;
 
-    QString currentName = ui->stationsList->currentItem()->text().split("\n").at(0);
     QString currentUrl = ui->stationsList->currentItem()->toolTip();
+    QString currentName = stationsDb.getStationName(currentUrl);
+    QString currentGenre = stationsDb.getStationGenre(currentUrl);
+    QString currentCountry = stationsDb.getStationCountry(currentUrl);
 
     bool ok1, ok2, ok3, ok4;
     QString name, url, genre, country;
@@ -323,9 +325,9 @@ void MainWindow::on_editStationButton_clicked()
     if ( !ok1 ) return;
     url = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Url: "), QLineEdit::Normal, currentUrl, &ok2, 0);
     if (!ok2 ) return;
-    genre = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Genre: "), QLineEdit::Normal, QString(), &ok3, 0);
+    genre = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Genre: "), QLineEdit::Normal, currentGenre, &ok3, 0);
     if (!ok3 ) return;
-    country = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Country: "), QLineEdit::Normal, QString(), &ok4, 0);
+    country = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Country: "), QLineEdit::Normal, currentCountry, &ok4, 0);
     if (!ok4 ) return;
 
     stationsDb.updateStation(currentUrl, name, url, genre, country);
