@@ -19,11 +19,13 @@ public:
     explicit SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
 
+signals:
+    void saveButtonClicked();
+
 private slots:
     void on_icon2Button_clicked();
     void on_icon1Button_clicked();
-
-    void on_pushButton_clicked();
+    void on_saveButton_clicked();
 
 private:
     Ui::SettingsDialog *ui;
@@ -32,6 +34,9 @@ private:
     QLabel labelBox;
 
     bool hideWhenClosing;
+    bool showNotifications;
+    bool showNotificationsOnlyWhenScreenIsOn;
+    bool showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow;
 
     void setIcons();
     void readSettings();
