@@ -352,3 +352,31 @@ void StationsDB::addDefaultStations()
 }
 
 
+
+QString StationsDB::getStationName(QString url)
+{
+    QSqlQuery query( db );
+    query.exec(QString("SELECT name FROM stations WHERE url='%1'").arg(url)) ;
+    query.next();
+
+    return query.value(0).toString();
+
+}
+
+QString StationsDB::getStationGenre(QString url)
+{
+    QSqlQuery query( db );
+    query.exec(QString("SELECT genre FROM stations WHERE url='%1'").arg(url)) ;
+    query.next();
+
+    return query.value(0).toString();
+}
+
+QString StationsDB::getStationCountry(QString url)
+{
+    QSqlQuery query( db );
+    query.exec(QString("SELECT country FROM stations WHERE url='%1'").arg(url)) ;
+    query.next();
+
+    return query.value(0).toString();
+}
