@@ -13,10 +13,16 @@ public:
     StationsDB();
 
     QStringList getFullStationList(OrderBy orderBy);
+    QStringList getFavouriteList();
     QStringList getGenreList();
     QStringList getCountryList();
     QStringList getListFilteredByGenre(QString filter, OrderBy orderBy);
     QStringList getListFilteredByCountry(QString filter, OrderBy orderBy);
+
+    QString getStationName(QString url);
+    QString getStationGenre(QString url);
+    QString getStationCountry(QString url);
+
     void checkDB();
     void clearDB();
     void restoreDefaultDB();
@@ -26,7 +32,6 @@ public:
     void deleteStation(QString url);
     void updateStation(QString currentUrl, QString name, QString url, QString genre, QString country);
     void setFavourite(QString url, bool choice);
-    QStringList getFavouriteList();
 
 private:
     QSqlDatabase db;
